@@ -1,7 +1,6 @@
-#ifndef __YLISTBOX_H
-#define __YLISTBOX_H
+#ifndef YLISTBOX_H
+#define YLISTBOX_H
 
-#include "ywindow.h"
 #include "yscrollbar.h"
 #include "yscrollview.h"
 
@@ -10,24 +9,18 @@ class YIcon;
 
 class YListItem {
 public:
-    YListItem();
-    virtual ~YListItem();
-
-    YListItem *getNext();
-    YListItem *getPrev();
-    void setNext(YListItem *next);
-    void setPrev(YListItem *prev);
+    YListItem() : fSelected(false) { }
+    virtual ~YListItem() { }
 
     bool getSelected() { return fSelected; }
-    void setSelected(bool aSelected);
+    void setSelected(bool aSelected) { fSelected = aSelected; }
 
-    virtual int getOffset();
-
-    virtual ustring getText();
-    virtual ref<YIcon> getIcon();
+    virtual int getOffset() { return 0; }
+    virtual int getWidth();
+    virtual ustring getText() { return null; }
+    virtual ref<YIcon> getIcon() { return null; }
 private:
-    bool fSelected; // !!! remove this from here
-    YListItem *fPrevItem, *fNextItem;
+    bool fSelected;
 };
 
 class YListBox:
@@ -41,7 +34,8 @@ public:
     virtual ~YListBox();
 
     void addItem(YListItem *item);
-    void addAfter(YListItem *prev, YListItem *item);
+    void addAfter(YListItem *after, YListItem *item);
+    void addBefore(YListItem *before, YListItem *item);
     void removeItem(YListItem *item);
 
     virtual void configure(const YRect2 &r);
@@ -65,13 +59,10 @@ public:
     bool hasSelection();
     virtual void activateItem(YListItem *item);
 
-    YListItem *getFirst() const { return fFirst; }
-    YListItem *getLast() const { return fLast; }
-
-    int getItemCount();
+    int getItemCount() const { return fItems.getCount(); }
     YListItem *getItem(int item);
     int findItemByPoint(int x, int y);
-    int findItem(YListItem *item);
+    int findItem(YListItem *item) const { return find(fItems, item); }
     int getLineHeight();
 
     int maxWidth();
@@ -91,13 +82,11 @@ private:
     YScrollBar *fVerticalScroll;
     YScrollBar *fHorizontalScroll;
     YScrollView *fView;
-    YListItem *fFirst, *fLast;
-    int fItemCount;
-    YListItem **fItems;
 
     int fOffsetX;
     int fOffsetY;
     int fMaxWidth;
+    int fWidestItem;
     int fFocusedItem;
     int fSelectStart, fSelectEnd;
     bool fDragging;
@@ -108,7 +97,6 @@ private:
 
     static int fAutoScrollDelta;
 
-    bool isItemSelected(int item);
     void selectItem(int item, bool sel);
     void selectItems(int selStart, int selEnd, bool sel);
     void paintItems(int selStart, int selEnd);
@@ -127,6 +115,13 @@ private:
 
     lazy<YTimer> fTimer;
     ref<YImage> fGradient;
+
+    typedef YArray<YListItem*> ArrayType;
+    ArrayType fItems;
+
+protected:
+    typedef ArrayType::IterType IterType;
+    IterType getIterator() { return fItems.iterator(); }
 };
 
 #endif
